#!/bin/bash

# Packager : Son|c <emmanuel.bailleul@gmail.com>
# Source :http://apache.cict.fr/spamassassin/source/Mail-SpamAssassin-3.2.4.tar.gz

sourcefile="$(grep -i '# *source *:' $0 |rev |cut -d '/' -f 1|rev)"
softversion="$(echo $sourcefile |rev |cut -c 8- |cut -d '-' -f1 | rev)"
perlversion="$(perl --version |grep '^This is perl' | cut -d ' ' -f 4 |cut -c 2-)"
packageversion='54.1'
softname="$(echo $sourcefile|rev|cut -d '-' -f 2- |rev)"
arch='i486'
cpu='i686'

buildir=$(pwd)

if [ ! -e sourcefile ]; then
    wget "$(grep -i '# *source *:' $0 | cut -d ':' -f 2-)"
fi

srcpkg="$buildir/$sourcefile"
src="$buildir/$softname-$softversion"
package="perl-$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
export CFLAGS="-O2 -march=$arch -mtune=$cpu"

# Adjust owner/perms to standard values:
chown -R root:root .
find . -perm 555 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;

# Build module
cd $src
chown -R root.root .
perl Makefile.PL CONFDIR=/etc/spamassassin DESTDIR=$dest CONTACT_ADDRESS="http://spamassassin.apache.org/"
make
make install DESTDIR=$dest

# Strip everything:
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# docs
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a Changes LICENSE INSTALL MANIFEST README NOTICE PACKAGING TRADEMARK USAGE UPGRADE sample-spam.txt sample-nonspam.txt \
$dest/usr/doc/$softname-$softversion/
chmod -R 644 $dest/usr/doc/$softname-$softversion/*


# Cleanup
( cd $dest/usr/share
  mv man .. )
chmod 644 $dest/usr/man/man?/*
#rm -rf $dest/usr/share
cp -rf $dest/usr/lib/perl5/site_perl/$perlversion/* $dest/usr/lib/perl5/$perlversion/
rm -rf $dest/usr/lib/perl5/site_perl/$perlversion/*

# Gzip man !
gzip -9 $dest/usr/man/man?/*

cd $buildir

# Slack desc

mkdir -p $dest/install

cat << EODESC > "$dest/install/slack-desc"
#       |-----handy-ruler------------------------------------------------------|
perl-Mail-SpamAssassin: Mail::SpamAssassin  Perl module
perl-Mail-SpamAssassin:
perl-Mail-SpamAssassin: SpamAssassin is a mail filter which attempts to
perl-Mail-SpamAssassin: identify spam using a variety of mechanisms including
perl-Mail-SpamAssassin: text analysis, Bayesian filtering, DNS blocklists,
perl-Mail-SpamAssassin: and collaborative filtering databases.
perl-Mail-SpamAssassin: 
perl-Mail-SpamAssassin: SpamAssassin is a project of the Apache Software
perl-Mail-SpamAssassin: Foundation (ASF)
perl-Mail-SpamAssassin:
perl-Mail-SpamAssassin:  
EODESC

# Welcome home

mkdir -p $dest/usr/src/$softname-$softversion
cp $buildir/build-perl-$softname.sh $dest/usr/src/$softname-$softversion/

# adding the perllocal.pod mechanism

PERLVERSION=$(perl --version | grep v[0-9] | cut -d " " -f 4 | sed 's|v||g')
PERLBUILD=$(perl --version | grep v[0-9] | cut -d " " -f 7)
POD="usr/lib/perl5/${PERLVERSION}/${PERLBUILD}/perllocal.pod"
mv $dest/$POD $dest/$POD.$softname

cat << EOF > $dest/install/doinst.sh
perlpod() {
	# Get module name
        MODNAME=\$(head -1 ${POD}.\${1} |awk -F \| '{ print \$2 }' |sed 's/>//g')
        # get versions first just to make it easier
        MODVERNEW=\$(grep -m 1 -A 21 \${MODNAME} ${POD}.\${1} | sed 's/>//g' | awk '/VERSION/ {print \$2}')
        MODVEROLD=\$(grep -m 1 -A 21 \${MODNAME} ${POD} | sed 's/>//g' | awk '/VERSION/ {print \$2}')
        # check for pod file first off and simply use the new one if it doesn't exist
        if [ ! -f "${POD}" ]; then
                 mv ${POD}.\${1} ${POD}
        # if it does exist we need to look for the given module name in it
        elif [ ! "\$(grep -m 1 \${MODNAME} ${POD})" ]; then
                # if we don't find the name we can append our pod to the end of the original pod
                cat ${POD}.\${1} >> ${POD} && rm ${POD}.\${1}
        else
                # if we do find the module is already installed we need to check its version
                if [ "\${MODVERNEW}" != "\${MODVEROLD}" ]; then
                        # change version
                        firstline=\$(grep -m 1 -n \${MODNAME} ${POD} | awk -F: '{print \$1}')
                        lastline=\$((firstline+21))
                        sed -i "\${firstline},\${lastline}d" ${POD}
                        cat ${POD}.\${1} >> ${POD}
                        rm ${POD}.\${1}
                else
                        rm ${POD}.\${1}
                fi
        fi
}
perlpod $softname
config() {
  NEW="\$1"
  OLD="\`dirname \$NEW\`/\`basename \$NEW .new\`"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ "\`cat \$OLD | md5sum\`" = "\`cat \$NEW | md5sum\`" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/spamassassin/local.cf.new
config etc/spamassassin/init.pre.new
config etc/spamassassin/v310.pre.new
config etc/spamassassin/v312.pre.new
config etc/spamassassin/v320.pre.new
EOF

mv $dest/etc/spamassassin/local.cf $dest/etc/spamassassin/local.cf.new
mv $dest/etc/spamassassin/init.pre $dest/etc/spamassassin/init.pre.new
mv $dest/etc/spamassassin/v310.pre $dest/etc/spamassassin/v310.pre.new
mv $dest/etc/spamassassin/v312.pre $dest/etc/spamassassin/v312.pre.new
mv $dest/etc/spamassassin/v320.pre $dest/etc/spamassassin/v320.pre.new

#------------------( Create The *.dep File )

cd $dest
requiredbuilder -z $dest > $buildir/$package.dep

# And finally, a package

cd $dest

makepkg  -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5

# Create src file
echo "$srcfile" > $package.src
